summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ChangeLog3
-rw-r--r--NEWS5
-rw-r--r--doc/de/autogen/user/weechat_commands.txt12
-rw-r--r--doc/de/autogen/user/weechat_options.txt10
-rw-r--r--doc/en/autogen/user/weechat_commands.txt12
-rw-r--r--doc/en/autogen/user/weechat_options.txt10
-rw-r--r--doc/fr/autogen/user/weechat_commands.txt12
-rw-r--r--doc/fr/autogen/user/weechat_options.txt10
-rw-r--r--doc/it/autogen/user/weechat_commands.txt12
-rw-r--r--doc/it/autogen/user/weechat_options.txt10
-rw-r--r--doc/ja/autogen/user/weechat_commands.txt22
-rw-r--r--doc/ja/autogen/user/weechat_options.txt10
-rw-r--r--doc/pl/autogen/user/weechat_commands.txt12
-rw-r--r--doc/pl/autogen/user/weechat_options.txt10
-rw-r--r--po/cs.po37
-rw-r--r--po/de.po40
-rw-r--r--po/es.po37
-rw-r--r--po/fr.po52
-rw-r--r--po/hu.po33
-rw-r--r--po/it.po36
-rw-r--r--po/ja.po37
-rw-r--r--po/pl.po36
-rw-r--r--po/pt_BR.po38
-rw-r--r--po/ru.po36
-rw-r--r--po/tr.po26
-rw-r--r--po/weechat.pot26
-rw-r--r--src/core/wee-command.c28
-rw-r--r--src/core/wee-config.c12
-rw-r--r--src/core/wee-config.h12
-rw-r--r--src/core/wee-upgrade.c2
-rw-r--r--src/core/weechat.c2
-rw-r--r--src/gui/gui-buffer.h2
-rw-r--r--src/gui/gui-layout.c42
-rw-r--r--src/gui/gui-layout.h6
-rw-r--r--src/gui/gui-window.c4
35 files changed, 374 insertions, 320 deletions
diff --git a/ChangeLog b/ChangeLog
index d950c688a..443105aaa 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -29,7 +29,8 @@ http://weechat.org/files/releasenotes/ReleaseNotes-devel.html[release notes]
* core: use "+" separator to make a logical "and" between tags in command
/filter, option weechat.look.highlight_tags and buffer property
"highlight_tags"
-* core: rename options save/reset to store/del in command /layout
+* core: rename options save/reset to store/del in command /layout, rename
+ option weechat.look.save_layout_on_exit to weechat.look.store_layout_on_exit
* core: add options weechat.look.buffer_auto_renumber and
weechat.look.buffer_position, add option "renumber" in command /buffer, add
bar item "buffer_last_number" (task #12766)
diff --git a/NEWS b/NEWS
index c95c16de9..8f0d0dd9f 100644
--- a/NEWS
+++ b/NEWS
@@ -13,6 +13,11 @@ http://weechat.org/files/changelog/ChangeLog-devel.html[ChangeLog]
== Version 0.4.3 (under dev)
+=== Layout
+
+Option 'weechat.look.save_layout_on_exit' has been renamed to
+'weechat.look.store_layout_on_exit'.
+
=== Colors in messages
The color code for "reverse video" in IRC message has been fixed: now WeeChat
diff --git a/doc/de/autogen/user/weechat_commands.txt b/doc/de/autogen/user/weechat_commands.txt
index 5070f5ada..7d44b1df7 100644
--- a/doc/de/autogen/user/weechat_commands.txt
+++ b/doc/de/autogen/user/weechat_commands.txt
@@ -483,16 +483,16 @@ Beispiele:
rename <name> <new_name>
store: store current buffers/windows in a layout
- apply: apply saved layout
+ apply: apply stored layout
leave: leave current layout (does not update any layout)
- del: delete buffers and/or windows in a saved layout
+ del: delete buffers and/or windows in a stored layout
(if neither "buffers" nor "windows" is given after the name, the layout is deleted)
rename: rename a layout
- name: name for saved layout (default is "default")
-buffers: save/apply only buffers (order of buffers)
-windows: save/apply only windows (buffer displayed by each window)
+ name: name for stored layout (default is "default")
+buffers: store/apply only buffers (order of buffers)
+windows: store/apply only windows (buffer displayed by each window)
-Without argument, this command displays saved layouts.
+Without argument, this command displays stored layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/de/autogen/user/weechat_options.txt b/doc/de/autogen/user/weechat_options.txt
index f7ae7f0f2..f67425203 100644
--- a/doc/de/autogen/user/weechat_options.txt
+++ b/doc/de/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** Typ: boolesch
** Werte: on, off (Standardwert: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** Beschreibung: `beim Beenden wird das aktuelle Layout automatisch gesichert (Buffer, Fenster oder beides)`
-** Typ: integer
-** Werte: none, buffers, windows, all (Standardwert: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** Beschreibung: `Anzahl der zu scrollenden Zeilen wenn seitenweise geblättert wird (Bild hoch/runter)`
** Typ: integer
@@ -838,6 +833,11 @@
** Typ: Zeichenkette
** Werte: beliebige Zeichenkette (Standardwert: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** Beschreibung: `store layout on exit (buffers, windows, or both)`
+** Typ: integer
+** Werte: none, buffers, windows, all (Standardwert: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** Beschreibung: `number of spaces used to display tabs in messages`
** Typ: integer
diff --git a/doc/en/autogen/user/weechat_commands.txt b/doc/en/autogen/user/weechat_commands.txt
index 3dc69a684..6df8db094 100644
--- a/doc/en/autogen/user/weechat_commands.txt
+++ b/doc/en/autogen/user/weechat_commands.txt
@@ -483,16 +483,16 @@ Examples:
rename <name> <new_name>
store: store current buffers/windows in a layout
- apply: apply saved layout
+ apply: apply stored layout
leave: leave current layout (does not update any layout)
- del: delete buffers and/or windows in a saved layout
+ del: delete buffers and/or windows in a stored layout
(if neither "buffers" nor "windows" is given after the name, the layout is deleted)
rename: rename a layout
- name: name for saved layout (default is "default")
-buffers: save/apply only buffers (order of buffers)
-windows: save/apply only windows (buffer displayed by each window)
+ name: name for stored layout (default is "default")
+buffers: store/apply only buffers (order of buffers)
+windows: store/apply only windows (buffer displayed by each window)
-Without argument, this command displays saved layouts.
+Without argument, this command displays stored layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/en/autogen/user/weechat_options.txt b/doc/en/autogen/user/weechat_options.txt
index 5c1b4e4ba..8a2776fcc 100644
--- a/doc/en/autogen/user/weechat_options.txt
+++ b/doc/en/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** type: boolean
** values: on, off (default value: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** description: `save layout on exit (buffers, windows, or both)`
-** type: integer
-** values: none, buffers, windows, all (default value: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** description: `how many lines to scroll by with scroll_up and scroll_down`
** type: integer
@@ -838,6 +833,11 @@
** type: string
** values: any string (default value: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** description: `store layout on exit (buffers, windows, or both)`
+** type: integer
+** values: none, buffers, windows, all (default value: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** description: `number of spaces used to display tabs in messages`
** type: integer
diff --git a/doc/fr/autogen/user/weechat_commands.txt b/doc/fr/autogen/user/weechat_commands.txt
index d2ad06c27..165888764 100644
--- a/doc/fr/autogen/user/weechat_commands.txt
+++ b/doc/fr/autogen/user/weechat_commands.txt
@@ -483,16 +483,16 @@ Exemples:
rename <nom> <nouveau_nom>
store: stocker les tampons/fenêtres courants dans une disposition
- apply: appliquer une disposition sauvegardée
+ apply: appliquer une disposition stockée
leave: quitter la disposition courante (ne met à jour aucune disposition)
- del: supprimer les tampons et/ou fenêtres dans une disposition sauvegardée
+ del: supprimer les tampons et/ou fenêtres dans une disposition stockée
(si ni "buffers" ni "windows" n'est donné après le nom, la disposition est supprimée)
rename: renommer une disposition
- nom: nom pour la disposition sauvegardée (par défaut "default")
-buffers: sauver/appliquer seulement pour les tampons (ordre des tampons)
-windows: sauver/appliquer seulement pour les fenêtres (le tampon affiché par chaque fenêtre)
+ nom: nom pour la disposition stockée (par défaut "default")
+buffers: stocker/appliquer seulement pour les tampons (ordre des tampons)
+windows: stocker/appliquer seulement pour les fenêtres (le tampon affiché par chaque fenêtre)
-Sans paramètre, cette commande affiche les dispositions sauvegardées.
+Sans paramètre, cette commande affiche les dispositions stockées.
----
[[command_weechat_mouse]]
diff --git a/doc/fr/autogen/user/weechat_options.txt b/doc/fr/autogen/user/weechat_options.txt
index 33e7c5204..b14c51fac 100644
--- a/doc/fr/autogen/user/weechat_options.txt
+++ b/doc/fr/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** type: booléen
** valeurs: on, off (valeur par défaut: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** description: `sauve la disposition en quittant (tampons, fenêtres, ou les deux)`
-** type: entier
-** valeurs: none, buffers, windows, all (valeur par défaut: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** description: `nombre de lignes pour le défilement avec scroll_up et scroll_down`
** type: entier
@@ -838,6 +833,11 @@
** type: chaîne
** valeurs: toute chaîne (valeur par défaut: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** description: `stocker la disposition en quittant (tampons, fenêtres, ou les deux)`
+** type: entier
+** valeurs: none, buffers, windows, all (valeur par défaut: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** description: `nombre d'espaces utilisés pour afficher les tabulations dans les messages`
** type: entier
diff --git a/doc/it/autogen/user/weechat_commands.txt b/doc/it/autogen/user/weechat_commands.txt
index ca78ac9d6..118c0a7cf 100644
--- a/doc/it/autogen/user/weechat_commands.txt
+++ b/doc/it/autogen/user/weechat_commands.txt
@@ -483,16 +483,16 @@ Esempi:
rename <name> <new_name>
store: store current buffers/windows in a layout
- apply: apply saved layout
+ apply: apply stored layout
leave: leave current layout (does not update any layout)
- del: delete buffers and/or windows in a saved layout
+ del: delete buffers and/or windows in a stored layout
(if neither "buffers" nor "windows" is given after the name, the layout is deleted)
rename: rename a layout
- name: name for saved layout (default is "default")
-buffers: save/apply only buffers (order of buffers)
-windows: save/apply only windows (buffer displayed by each window)
+ name: name for stored layout (default is "default")
+buffers: store/apply only buffers (order of buffers)
+windows: store/apply only windows (buffer displayed by each window)
-Without argument, this command displays saved layouts.
+Without argument, this command displays stored layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/it/autogen/user/weechat_options.txt b/doc/it/autogen/user/weechat_options.txt
index ed911e131..0f605808f 100644
--- a/doc/it/autogen/user/weechat_options.txt
+++ b/doc/it/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** tipo: bool
** valori: on, off (valore predefinito: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** descrizione: `salva layout all'uscita (buffer, finestre, o entrambi)`
-** tipo: intero
-** valori: none, buffers, windows, all (valore predefinito: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** descrizione: `le righe da scorrere con scroll_up e scroll_down`
** tipo: intero
@@ -838,6 +833,11 @@
** tipo: stringa
** valori: qualsiasi stringa (valore predefinito: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** descrizione: `store layout on exit (buffers, windows, or both)`
+** tipo: intero
+** valori: none, buffers, windows, all (valore predefinito: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** descrizione: `number of spaces used to display tabs in messages`
** tipo: intero
diff --git a/doc/ja/autogen/user/weechat_commands.txt b/doc/ja/autogen/user/weechat_commands.txt
index 0ea144c52..a6d18d0ab 100644
--- a/doc/ja/autogen/user/weechat_commands.txt
+++ b/doc/ja/autogen/user/weechat_commands.txt
@@ -482,17 +482,17 @@ listdefault: デフォルトキーをリストアップ
del [<name>] [buffers|windows]
rename <name> <new_name>
- store: レイアウトに現在のバッファ/ウィンドウを保存
- apply: 保存されたレイアウトを適用
- leave: 現在のレイアウトを保持する (レイアウトを更新しない)
- del: レイアウトとして保存されているバッファとウィンドウを削除
- (名前の後に "バッファ" や "ウィンドウ" を指定しない場合、レイアウトを削除)
- rename: レイアウトのリネーム
- name: 保存されたレイアウトの名前 (初期状態は "default")
-buffers: バッファのみに対してレイアウトを保存/適用 (バッファの順番)
-windows: ウィンドウのみに対してレイアウトを保存/適用 (それぞれのウィンドウに表示されるバッファ)
-
-引数無しでは、保存されたレイアウトを表示します。
+ store: store current buffers/windows in a layout
+ apply: apply stored layout
+ leave: leave current layout (does not update any layout)
+ del: delete buffers and/or windows in a stored layout
+ (if neither "buffers" nor "windows" is given after the name, the layout is deleted)
+ rename: rename a layout
+ name: name for stored layout (default is "default")
+buffers: store/apply only buffers (order of buffers)
+windows: store/apply only windows (buffer displayed by each window)
+
+Without argument, this command displays stored layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/ja/autogen/user/weechat_options.txt b/doc/ja/autogen/user/weechat_options.txt
index 566353d16..f82f8fbaf 100644
--- a/doc/ja/autogen/user/weechat_options.txt
+++ b/doc/ja/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** タイプ: ブール
** 値: on, off (デフォルト値: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** 説明: `終了時にレイアウトを保存 (buffers、windows または both)`
-** タイプ: 整数
-** 値: none, buffers, windows, all (デフォルト値: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** 説明: `scroll_up と scroll_down でスクロールする行数`
** タイプ: 整数
@@ -838,6 +833,11 @@
** タイプ: 文字列
** 値: 未制約文字列 (デフォルト値: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** 説明: `store layout on exit (buffers, windows, or both)`
+** タイプ: 整数
+** 値: none, buffers, windows, all (デフォルト値: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** 説明: `number of spaces used to display tabs in messages`
** タイプ: 整数
diff --git a/doc/pl/autogen/user/weechat_commands.txt b/doc/pl/autogen/user/weechat_commands.txt
index 38feae0d7..6e6853123 100644
--- a/doc/pl/autogen/user/weechat_commands.txt
+++ b/doc/pl/autogen/user/weechat_commands.txt
@@ -483,16 +483,16 @@ Przykłady:
rename <name> <new_name>
store: store current buffers/windows in a layout
- apply: apply saved layout
+ apply: apply stored layout
leave: leave current layout (does not update any layout)
- del: delete buffers and/or windows in a saved layout
+ del: delete buffers and/or windows in a stored layout
(if neither "buffers" nor "windows" is given after the name, the layout is deleted)
rename: rename a layout
- name: name for saved layout (default is "default")
-buffers: save/apply only buffers (order of buffers)
-windows: save/apply only windows (buffer displayed by each window)
+ name: name for stored layout (default is "default")
+buffers: store/apply only buffers (order of buffers)
+windows: store/apply only windows (buffer displayed by each window)
-Without argument, this command displays saved layouts.
+Without argument, this command displays stored layouts.
----
[[command_weechat_mouse]]
diff --git a/doc/pl/autogen/user/weechat_options.txt b/doc/pl/autogen/user/weechat_options.txt
index b6e574d35..9b7b735f0 100644
--- a/doc/pl/autogen/user/weechat_options.txt
+++ b/doc/pl/autogen/user/weechat_options.txt
@@ -803,11 +803,6 @@
** typ: bool
** wartości: on, off (domyślna wartość: `on`)
-* [[option_weechat.look.save_layout_on_exit]] *weechat.look.save_layout_on_exit*
-** opis: `zapisz układ przy wyjściu (bufory, okna, lub oba)`
-** typ: liczba
-** wartości: none, buffers, windows, all (domyślna wartość: `none`)
-
* [[option_weechat.look.scroll_amount]] *weechat.look.scroll_amount*
** opis: `ile linii przewijać za pomocą scroll_up i scroll_down`
** typ: liczba
@@ -838,6 +833,11 @@
** typ: ciąg
** wartości: dowolny ciąg (domyślna wartość: `""`)
+* [[option_weechat.look.store_layout_on_exit]] *weechat.look.store_layout_on_exit*
+** opis: `store layout on exit (buffers, windows, or both)`
+** typ: liczba
+** wartości: none, buffers, windows, all (domyślna wartość: `none`)
+
* [[option_weechat.look.tab_width]] *weechat.look.tab_width*
** opis: `number of spaces used to display tabs in messages`
** typ: liczba
diff --git a/po/cs.po b/po/cs.po
index 97beb3804..ee748b5ef 100644
--- a/po/cs.po
+++ b/po/cs.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:20+0100\n"
"Last-Translator: Jiri Golembiovsky <golemj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -475,20 +475,21 @@ msgstr[1] "přidány %d nové klávesy"
msgstr[2] "přidáno %d nových kláves"
#, fuzzy
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr "Uložené rozložení bufferů:"
#, fuzzy
msgid " (current layout)"
msgstr "aktuální hodnota"
-msgid "No layout saved"
-msgstr "Nebylo uloženo žádné rozložení"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "jména polí"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr ""
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "%sTéma pro %s%s%s nastaveno %s"
#, fuzzy
msgid "buffers"
@@ -1736,17 +1737,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" save: uložit aktuální rozložení\n"
" apply: aplikovat uložené rozložení\n"
@@ -3072,9 +3073,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "uložit soubor s nastavením při ukončení"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "uložit rozložení při ukončení (buffery, okna nebo obojí)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "o kolik řádů posunou pomocí scroll_up a scroll_down"
@@ -3116,6 +3114,10 @@ msgstr ""
"povoleny"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "uložit rozložení při ukončení (buffery, okna nebo obojí)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "prefix pro zprávy akcí"
@@ -10091,6 +10093,9 @@ msgstr ""
msgid "Constants"
msgstr ""
+#~ msgid "No layout saved"
+#~ msgstr "Nebylo uloženo žádné rozložení"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sguntls: jméno hosta v certifikátu NODPOVÍDÁ \"%s\""
diff --git a/po/de.po b/po/de.po
index 1913636aa..2308268f7 100644
--- a/po/de.po
+++ b/po/de.po
@@ -22,7 +22,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.4.3-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:20+0100\n"
"Last-Translator: Nils Görs <weechatter@arcor.de>\n"
"Language-Team: German <weechatter@arcor.de>\n"
@@ -500,18 +500,20 @@ msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] "(%d) neue Taste hinzugefügt"
msgstr[1] "(%d) neue Tasten hinzugefügt (Kontext: \"%s\")"
-msgid "Saved layouts:"
+#, fuzzy
+msgid "Stored layouts:"
msgstr "gespeicherte Layouts:"
msgid " (current layout)"
msgstr " (aktuelles Layout)"
-msgid "No layout saved"
-msgstr "Kein Layout gespeichert"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "Auflistung der Layouts"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr "Layout %s%s%s gesichert in \"%s\" (aktuelles Layout: %s)"
msgid "buffers"
@@ -1947,17 +1949,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" add: erstellt ein Layout der zur Zeit verwendeten Buffer/Fenster\n"
" apply: das gespeicherte Layout anwenden\n"
@@ -3560,11 +3562,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "die aktuelle Konfiguration wird beim Beenden automatisch gesichert"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr ""
-"beim Beenden wird das aktuelle Layout automatisch gesichert (Buffer, Fenster "
-"oder beides)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr ""
"Anzahl der zu scrollenden Zeilen wenn seitenweise geblättert wird (Bild hoch/"
@@ -3612,6 +3609,12 @@ msgstr ""
"Die Schriftbreite muss exakt ein Zeichen betragen"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr ""
+"beim Beenden wird das aktuelle Layout automatisch gesichert (Buffer, Fenster "
+"oder beides)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr ""
"Lokalisation welche für die übersetzten Nachrichten verwendet werden soll"
@@ -11205,6 +11208,9 @@ msgstr "Type"
msgid "Constants"
msgstr "Konstanten"
+#~ msgid "No layout saved"
+#~ msgstr "Kein Layout gespeichert"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: der Hostname im Zertifikat \"%s\" stimmt NICHT überein"
diff --git a/po/es.po b/po/es.po
index 3a352546f..874d656a3 100644
--- a/po/es.po
+++ b/po/es.po
@@ -22,7 +22,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:21+0100\n"
"Last-Translator: Elián Hanisch <lambdae2@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -483,20 +483,21 @@ msgstr[0] "%d nuevo atajo agregado"
msgstr[1] "%d nuevos atajos agregados (contexto: \"%s\")"
#, fuzzy
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr "Esquema de buffers guardado:"
#, fuzzy
msgid " (current layout)"
msgstr "valor actual"
-msgid "No layout saved"
-msgstr "Ningún esquema guardado"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "nombres de barras"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr ""
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "%sTema para %s%s%s establecido el %s"
#, fuzzy
msgid "buffers"
@@ -1824,17 +1825,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" save: guarda el esquema actual\n"
" apply: aplica el esquema guardado\n"
@@ -3258,9 +3259,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "guardar archivo de configuración al salir"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "guardar esquema al salir (buffers, ventanas o ambos)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "cuántas líneas a desplazar con scroll_up y scroll_down"
@@ -3305,6 +3303,10 @@ msgstr ""
"permitidos"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "guardar esquema al salir (buffers, ventanas o ambos)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "localización para traducción de mensajes"
@@ -10361,6 +10363,9 @@ msgstr "Tipo"
msgid "Constants"
msgstr "Constantes"
+#~ msgid "No layout saved"
+#~ msgstr "Ningún esquema guardado"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: el hostname en el certificado NO concuerda con \"%s\""
diff --git a/po/fr.po b/po/fr.po
index 53978c44f..867c5ab84 100644
--- a/po/fr.po
+++ b/po/fr.po
@@ -21,8 +21,8 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
-"PO-Revision-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
+"PO-Revision-Date: 2014-01-21 21:51+0100\n"
"Last-Translator: Sébastien Helleu <flashcode@flashtux.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
"Language: fr\n"
@@ -486,19 +486,19 @@ msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] "%d nouvelle touche ajoutée (contexte: \"%s\")"
msgstr[1] "%d nouvelles touches ajoutées (contexte: \"%s\")"
-msgid "Saved layouts:"
-msgstr "Dispositions sauvegardées:"
+msgid "Stored layouts:"
+msgstr "Dispositions stockées:"
msgid " (current layout)"
msgstr " (disposition courante)"
-msgid "No layout saved"
-msgstr "Pas de disposition sauvée"
+msgid "No stored layouts"
+msgstr "Pas de disposition stockée"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr "Disposition des %s%s%s sauvée dans \"%s\" (disposition courante: %s)"
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "Disposition des %s%s%s stockée dans \"%s\" (disposition courante: %s)"
msgid "buffers"
msgstr "tampons"
@@ -1897,32 +1897,31 @@ msgstr ""
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" store: stocker les tampons/fenêtres courants dans une disposition\n"
-" apply: appliquer une disposition sauvegardée\n"
+" apply: appliquer une disposition stockée\n"
" leave: quitter la disposition courante (ne met à jour aucune disposition)\n"
-" del: supprimer les tampons et/ou fenêtres dans une disposition "
-"sauvegardée\n"
+" del: supprimer les tampons et/ou fenêtres dans une disposition stockée\n"
" (si ni \"buffers\" ni \"windows\" n'est donné après le nom, la "
"disposition est supprimée)\n"
" rename: renommer une disposition\n"
-" nom: nom pour la disposition sauvegardée (par défaut \"default\")\n"
-"buffers: sauver/appliquer seulement pour les tampons (ordre des tampons)\n"
-"windows: sauver/appliquer seulement pour les fenêtres (le tampon affiché par "
-"chaque fenêtre)\n"
+" nom: nom pour la disposition stockée (par défaut \"default\")\n"
+"buffers: stocker/appliquer seulement pour les tampons (ordre des tampons)\n"
+"windows: stocker/appliquer seulement pour les fenêtres (le tampon affiché "
+"par chaque fenêtre)\n"
"\n"
-"Sans paramètre, cette commande affiche les dispositions sauvegardées."
+"Sans paramètre, cette commande affiche les dispositions stockées."
msgid "mouse control"
msgstr "contrôle de la souris"
@@ -3486,9 +3485,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "sauvegarder la configuration en quittant"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "sauve la disposition en quittant (tampons, fenêtres, ou les deux)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "nombre de lignes pour le défilement avec scroll_up et scroll_down"
@@ -3531,6 +3527,9 @@ msgstr ""
"fenêtres (une valeur vide tracera une vraie ligne avec ncurses); la largeur "
"à l'écran doit être exactement d'un caractère"
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "stocker la disposition en quittant (tampons, fenêtres, ou les deux)"
+
msgid "number of spaces used to display tabs in messages"
msgstr ""
"nombre d'espaces utilisés pour afficher les tabulations dans les messages"
@@ -10959,6 +10958,9 @@ msgstr "Type"
msgid "Constants"
msgstr "Constantes"
+#~ msgid "No layout saved"
+#~ msgstr "Pas de disposition sauvée"
+
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: l'empreinte ne correspond PAS"
diff --git a/po/hu.po b/po/hu.po
index 8fb9efa77..7d2779907 100644
--- a/po/hu.po
+++ b/po/hu.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-06 10:16+0100\n"
"Last-Translator: Andras Voroskoi <voroskoi@frugalware.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -489,19 +489,20 @@ msgstr[0] "Nincs mellőzés megadva.\n"
msgstr[1] "Nincs mellőzés megadva.\n"
#, fuzzy
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr "a pufferek időbélyege"
msgid " (current layout)"
msgstr ""
-msgid "No layout saved"
-msgstr ""
+#, fuzzy
+msgid "No stored layouts"
+msgstr "Aliaszok listája:\n"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr ""
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "A %s%s%s szoba témája: "
#, fuzzy
msgid "buffers"
@@ -1541,17 +1542,17 @@ msgstr ""
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
msgid "mouse control"
@@ -2679,9 +2680,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "beállítások mentése kilépéskor"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr ""
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "a scroll_up és scroll_down hány sort görgessen"
@@ -2710,6 +2708,9 @@ msgid ""
"will draw a real line with ncurses); width on screen must be exactly one char"
msgstr ""
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr ""
+
#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "válasz ping üzenetre"
diff --git a/po/it.po b/po/it.po
index 59e087ee2..ec161878c 100644
--- a/po/it.po
+++ b/po/it.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:22+0100\n"
"Last-Translator: Esteban I. Ruiz Moreno <exio4.com@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -472,18 +472,20 @@ msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] "%d nuovo tasto aggiunto (contesto: \"%s\")"
msgstr[1] "%d nuovi tasti aggiunti (contesto: \"%s\")"
-msgid "Saved layouts:"
+#, fuzzy
+msgid "Stored layouts:"
msgstr "Layout salvati:"
msgid " (current layout)"
msgstr " (layout corrente)"
-msgid "No layout saved"
-msgstr "Nessun layout salvato"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "elenco dei layout"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr "Layout per %s%s%s salvato in \"%s\" (layout corrente: %s)"
msgid "buffers"
@@ -1858,17 +1860,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" save: salva il layout corrente\n"
" apply: applica il layout salvato\n"
@@ -3359,9 +3361,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "salva file di configurazione all'uscita"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "salva layout all'uscita (buffer, finestre, o entrambi)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "le righe da scorrere con scroll_up e scroll_down"
@@ -3406,6 +3405,10 @@ msgstr ""
"caratteri wide qui NON sono consentiti"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "salva layout all'uscita (buffer, finestre, o entrambi)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "locale usato per la traduzione dei messaggi"
@@ -10512,6 +10515,9 @@ msgstr "Tipo"
msgid "Constants"
msgstr "Costanti"
+#~ msgid "No layout saved"
+#~ msgstr "Nessun layout salvato"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: il nome host nel certificato NON coincide \"%s\""
diff --git a/po/ja.po b/po/ja.po
index 26f3ff75f..f7635618f 100644
--- a/po/ja.po
+++ b/po/ja.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:22+0100\n"
"Last-Translator: AYANOKOUZI, Ryuunosuke <i38w7i3@yahoo.co.jp>\n"
"Language-Team: Japanese <https://github.com/l/WeeChat>\n"
@@ -479,18 +479,20 @@ msgid "%d new key added"
msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] "%d 個の新しいキーを追加しました (コンテキスト: \"%s\")"
-msgid "Saved layouts:"
+#, fuzzy
+msgid "Stored layouts:"
msgstr "保存されたレイアウト:"
msgid " (current layout)"
msgstr " (現在のレイアウト)"
-msgid "No layout saved"
-msgstr "レイアウトが保存されていません"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "レイアウトのリスト"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr "%s%s%s のレイアウトを \"%s\" で保存しました (現在のレイアウト: %s)"
msgid "buffers"
@@ -1842,19 +1844,20 @@ msgstr ""
"store [<name>] [buffers|windows] || apply [<name>] [buffers|windows] || "
"leave || del [<name>] [buffers|windows] || rename <name> <new_name>"
+#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" store: レイアウトに現在のバッファ/ウィンドウを保存\n"
" apply: 保存されたレイアウトを適用\n"
@@ -3336,9 +3339,6 @@ msgstr "リードマーカー行の表示に使われる文字列 (行末まで
msgid "save configuration file on exit"
msgstr "終了時に設定ファイルを保存"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "終了時にレイアウトを保存 (buffers、windows または both)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "scroll_up と scroll_down でスクロールする行数"
@@ -3379,6 +3379,10 @@ msgstr ""
"クリーン上に描画した時の文字幅が 1 の文字を指定してください"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "終了時にレイアウトを保存 (buffers、windows または both)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "翻訳メッセージに利用するロケール"
@@ -10538,6 +10542,9 @@ msgstr "タイプ"
msgid "Constants"
msgstr "定数"
+#~ msgid "No layout saved"
+#~ msgstr "レイアウトが保存されていません"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: 証明書内のホストネームは \"%s\" とマッチしません"
diff --git a/po/pl.po b/po/pl.po
index 6e2e46a94..216df5283 100644
--- a/po/pl.po
+++ b/po/pl.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:23+0100\n"
"Last-Translator: Krzysztof Korościk <soltys@szluug.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -485,18 +485,20 @@ msgstr[0] "dodano %d nowy klawisz"
msgstr[1] "dodano %d nowe klawisze (kontekst: \"%s\")"
msgstr[2] "dodano %d nowych klawiszy (kontekst: \"%s\")"
-msgid "Saved layouts:"
+#, fuzzy
+msgid "Stored layouts:"
msgstr "Zapisane układy:"
msgid " (current layout)"
msgstr " (aktualny układ)"
-msgid "No layout saved"
-msgstr "Nie zapisano żadnego układu"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "lista układów"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr "Układ dla %s%s%s zapisano w \"%s\" (obecny układ: %s)"
msgid "buffers"
@@ -1893,17 +1895,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" add: tworzy układ używając obecnych buforów/okien\n"
" apply: stosuje zapisany układ\n"
@@ -3423,9 +3425,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "zapisz plik konfiguracyjny przy wyjściu"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "zapisz układ przy wyjściu (bufory, okna, lub oba)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "ile linii przewijać za pomocą scroll_up i scroll_down"
@@ -3469,6 +3468,10 @@ msgstr ""
"szerokość na ekranie musi wynosić dokładnie jeden znak"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "zapisz układ przy wyjściu (bufory, okna, lub oba)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "zestaw znaków użyty do tłumaczenia wiadomości"
@@ -10731,6 +10734,9 @@ msgstr "Typ"
msgid "Constants"
msgstr "Stałe"
+#~ msgid "No layout saved"
+#~ msgstr "Nie zapisano żadnego układu"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: nazwa hosta w certyfikacie NIE pasuje do \"%s\""
diff --git a/po/pt_BR.po b/po/pt_BR.po
index b5aa62fbb..6b26bcbcf 100644
--- a/po/pt_BR.po
+++ b/po/pt_BR.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-18 21:23+0100\n"
"Last-Translator: Sergio Durigan Junior <sergiosdj@gmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -508,19 +508,21 @@ msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] "%d nova tecla adicionada"
msgstr[1] "%d novas teclas adicionadas (context: \"%s\")"
-msgid "Saved layouts:"
+#, fuzzy
+msgid "Stored layouts:"
msgstr "Disposição dos buffers salvada:"
msgid " (current layout)"
msgstr " (disposição atual)"
-msgid "No layout saved"
-msgstr "Nenhuma disposição salva"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "nomes das barras"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr ""
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "Disposição de %s%s%s reconfigurada em \"%s\""
msgid "buffers"
msgstr "buffers"
@@ -1801,17 +1803,17 @@ msgstr ""
#, fuzzy
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
" save: salvar a disposição atual\n"
" apply: aplicar a disposição salva\n"
@@ -3160,9 +3162,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "salva arquivo de configuração na saída"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr "salva disposição na saída (buffers, janelas, ou ambos)"
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "quantas linhas rolar com scroll_up e scroll_down"
@@ -3203,6 +3202,10 @@ msgstr ""
"extendidos NÃO são aceitos aqui"
#, fuzzy
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr "salva disposição na saída (buffers, janelas, ou ambos)"
+
+#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "prefixo para mensagens de ação"
@@ -9723,6 +9726,9 @@ msgstr ""
msgid "Constants"
msgstr ""
+#~ msgid "No layout saved"
+#~ msgstr "Nenhuma disposição salva"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "%sgnutls: o hostname no certificado NÃO É semelhante a \"%s\""
diff --git a/po/ru.po b/po/ru.po
index e520c209b..21e51d18d 100644
--- a/po/ru.po
+++ b/po/ru.po
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-06 10:17+0100\n"
"Last-Translator: Aleksey V Zapparov AKA ixti <ixti@member.fsf.org>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -499,20 +499,21 @@ msgstr[1] "Игнорирования не заданы.\n"
msgstr[2] "Игнорирования не заданы.\n"
#, fuzzy
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr "время в буферах"
#, fuzzy
msgid " (current layout)"
msgstr "текущее значение"
-msgid "No layout saved"
-msgstr "Нет сохранённых раскладок"
+#, fuzzy
+msgid "No stored layouts"
+msgstr "Список сокращений:\n"
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
-#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
-msgstr ""
+#, fuzzy, c-format
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
+msgstr "Тема канала %s%s%s: "
#, fuzzy
msgid "buffers"
@@ -1564,17 +1565,17 @@ msgstr ""
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
msgid "mouse control"
@@ -2711,9 +2712,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr "сохранять конфигурационный файл при выходе"
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr ""
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr "количество проматываемых кнопками PageUp и PageDown строк"
@@ -2742,6 +2740,9 @@ msgid ""
"will draw a real line with ncurses); width on screen must be exactly one char"
msgstr ""
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr ""
+
#, fuzzy
msgid "number of spaces used to display tabs in messages"
msgstr "ответить на ping"
@@ -9536,6 +9537,9 @@ msgstr ""
msgid "Constants"
msgstr ""
+#~ msgid "No layout saved"
+#~ msgstr "Нет сохранённых раскладок"
+
#, fuzzy
#~ msgid "%sgnutls: fingerprint does NOT match"
#~ msgstr "Не могу записать лог-файл \"%s\"\n"
diff --git a/po/tr.po b/po/tr.po
index 2bcbf01a3..cbfc6f9a5 100644
--- a/po/tr.po
+++ b/po/tr.po
@@ -20,7 +20,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2014-01-06 10:17+0100\n"
"Last-Translator: Hasan Kiran <sunder67@hotmail.com>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -443,18 +443,18 @@ msgid "%d new key added"
msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] ""
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr ""
msgid " (current layout)"
msgstr ""
-msgid "No layout saved"
+msgid "No stored layouts"
msgstr ""
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr ""
msgid "buffers"
@@ -1391,17 +1391,17 @@ msgstr ""
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
msgid "mouse control"
@@ -2420,9 +2420,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr ""
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr ""
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr ""
@@ -2451,6 +2448,9 @@ msgid ""
"will draw a real line with ncurses); width on screen must be exactly one char"
msgstr ""
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr ""
+
msgid "number of spaces used to display tabs in messages"
msgstr ""
diff --git a/po/weechat.pot b/po/weechat.pot
index b000fef4e..d8d89a589 100644
--- a/po/weechat.pot
+++ b/po/weechat.pot
@@ -21,7 +21,7 @@ msgid ""
msgstr ""
"Project-Id-Version: WeeChat 0.4.1-dev\n"
"Report-Msgid-Bugs-To: flashcode@flashtux.org\n"
-"POT-Creation-Date: 2014-01-21 15:28+0100\n"
+"POT-Creation-Date: 2014-01-21 21:52+0100\n"
"PO-Revision-Date: 2013-02-14 18:20+0100\n"
"Last-Translator: FULL NAME <EMAIL@ADDRESS>\n"
"Language-Team: weechat-dev <weechat-dev@nongnu.org>\n"
@@ -444,18 +444,18 @@ msgid_plural "%d new keys added (context: \"%s\")"
msgstr[0] ""
msgstr[1] ""
-msgid "Saved layouts:"
+msgid "Stored layouts:"
msgstr ""
msgid " (current layout)"
msgstr ""
-msgid "No layout saved"
+msgid "No stored layouts"
msgstr ""
#. TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows"
#, c-format
-msgid "Layout of %s%s%s saved in \"%s\" (current layout: %s)"
+msgid "Layout of %s%s%s stored in \"%s\" (current layout: %s)"
msgstr ""
msgid "buffers"
@@ -1394,17 +1394,17 @@ msgstr ""
msgid ""
" store: store current buffers/windows in a layout\n"
-" apply: apply saved layout\n"
+" apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
-" del: delete buffers and/or windows in a saved layout\n"
+" del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after the name, "
"the layout is deleted)\n"
" rename: rename a layout\n"
-" name: name for saved layout (default is \"default\")\n"
-"buffers: save/apply only buffers (order of buffers)\n"
-"windows: save/apply only windows (buffer displayed by each window)\n"
+" name: name for stored layout (default is \"default\")\n"
+"buffers: store/apply only buffers (order of buffers)\n"
+"windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
-"Without argument, this command displays saved layouts."
+"Without argument, this command displays stored layouts."
msgstr ""
msgid "mouse control"
@@ -2422,9 +2422,6 @@ msgstr ""
msgid "save configuration file on exit"
msgstr ""
-msgid "save layout on exit (buffers, windows, or both)"
-msgstr ""
-
msgid "how many lines to scroll by with scroll_up and scroll_down"
msgstr ""
@@ -2453,6 +2450,9 @@ msgid ""
"will draw a real line with ncurses); width on screen must be exactly one char"
msgstr ""
+msgid "store layout on exit (buffers, windows, or both)"
+msgstr ""
+
msgid "number of spaces used to display tabs in messages"
msgstr ""
diff --git a/src/core/wee-config.c b/src/core/wee-config.c
index 249fe48a3..61061fb3e 100644
--- a/src/core/wee-config.c
+++ b/src/core/wee-config.c
@@ -159,13 +159,13 @@ struct t_config_option *config_look_read_marker;
struct t_config_option *config_look_read_marker_always_show;
struct t_config_option *config_look_read_marker_string;
struct t_config_option *config_look_save_config_on_exit;
-struct t_config_option *config_look_save_layout_on_exit;
struct t_config_option *config_look_scroll_amount;
struct t_config_option *config_look_scroll_bottom_after_switch;
struct t_config_option *config_look_scroll_page_percent;
struct t_config_option *config_look_search_text_not_found_alert;
struct t_config_option *config_look_separator_horizontal;
struct t_config_option *config_look_separator_vertical;
+struct t_config_option *config_look_store_layout_on_exit;
struct t_config_option *config_look_tab_width;
struct t_config_option *config_look_time_format;
struct t_config_option *config_look_window_auto_zoom;
@@ -2581,11 +2581,6 @@ config_weechat_init_options ()
"save_config_on_exit", "boolean",
N_("save configuration file on exit"),
NULL, 0, 0, "on", NULL, 0, NULL, NULL, &config_change_save_config_on_exit, NULL, NULL, NULL);
- config_look_save_layout_on_exit = config_file_new_option (
- weechat_config_file, ptr_section,
- "save_layout_on_exit", "integer",
- N_("save layout on exit (buffers, windows, or both)"),
- "none|buffers|windows|all", 0, 0, "none", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
config_look_scroll_amount = config_file_new_option (
weechat_config_file, ptr_section,
"scroll_amount", "integer",
@@ -2627,6 +2622,11 @@ config_weechat_init_options ()
"width on screen must be exactly one char"),
NULL, 0, 0, "", NULL, 0,
&config_check_separator, NULL, &config_change_buffers, NULL, NULL, NULL);
+ config_look_store_layout_on_exit = config_file_new_option (
+ weechat_config_file, ptr_section,
+ "store_layout_on_exit", "integer",
+ N_("store layout on exit (buffers, windows, or both)"),
+ "none|buffers|windows|all", 0, 0, "none", NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL);
config_look_tab_width = config_file_new_option (
weechat_config_file, ptr_section,
"tab_width", "integer",
diff --git a/src/core/wee-config.h b/src/core/wee-config.h
index dc744a6dc..e77578331 100644
--- a/src/core/wee-config.h
+++ b/src/core/wee-config.h
@@ -91,12 +91,12 @@ enum t_config_look_read_marker
CONFIG_LOOK_READ_MARKER_CHAR,
};
-enum t_config_look_save_layout_on_exit
+enum t_config_look_store_layout_on_exit
{
- CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_NONE = 0,
- CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_BUFFERS,
- CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_WINDOWS,
- CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_ALL,
+ CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_NONE = 0,
+ CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_BUFFERS,
+ CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_WINDOWS,
+ CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_ALL,
};
extern struct t_config_file *weechat_config_file;
@@ -191,13 +191,13 @@ extern struct t_config_option *config_look_read_marker;
extern struct t_config_option *config_look_read_marker_always_show;
extern struct t_config_option *config_look_read_marker_string;
extern struct t_config_option *config_look_save_config_on_exit;
-extern struct t_config_option *config_look_save_layout_on_exit;
extern struct t_config_option *config_look_scroll_amount;
extern struct t_config_option *config_look_scroll_bottom_after_switch;
extern struct t_config_option *config_look_scroll_page_percent;
extern struct t_config_option *config_look_search_text_not_found_alert;
extern struct t_config_option *config_look_separator_horizontal;
extern struct t_config_option *config_look_separator_vertical;
+extern struct t_config_option *config_look_store_layout_on_exit;
extern struct t_config_option *config_look_tab_width;
extern struct t_config_option *config_look_time_format;
extern struct t_config_option *config_look_window_auto_zoom;
diff --git a/src/core/wee-upgrade.c b/src/core/wee-upgrade.c
index 682f1bc07..fbf8ba8b4 100644
--- a/src/core/wee-upgrade.c
+++ b/src/core/wee-upgrade.c
@@ -354,7 +354,7 @@ upgrade_weechat_save_layout_window (struct t_upgrade_file *upgrade_file)
if (ptr_layout)
{
- gui_layout_window_save (ptr_layout);
+ gui_layout_window_store (ptr_layout);
/* save tree with layout of windows */
rc = upgrade_weechat_save_layout_window_tree (upgrade_file, ptr_layout->layout_windows);
diff --git a/src/core/weechat.c b/src/core/weechat.c
index 4dfe1ff9c..675d97612 100644
--- a/src/core/weechat.c
+++ b/src/core/weechat.c
@@ -476,7 +476,7 @@ main (int argc, char *argv[])
gui_main_loop (); /* WeeChat main loop */
- gui_layout_save_on_exit (); /* save layout */
+ gui_layout_store_on_exit (); /* store layout */
plugin_end (); /* end plugin interface(s) */
if (CONFIG_BOOLEAN(config_look_save_config_on_exit))
(void) config_weechat_write (); /* save WeeChat config file */
diff --git a/src/gui/gui-buffer.h b/src/gui/gui-buffer.h
index 64b16b9d1..7f9056edb 100644
--- a/src/gui/gui-buffer.h
+++ b/src/gui/gui-buffer.h
@@ -82,7 +82,7 @@ struct t_gui_buffer
char *plugin_name_for_upgrade; /* plugin name when upgrading */
int number; /* buffer number (first is 1) */
- int layout_number; /* number of buffer saved in layout */
+ int layout_number; /* number of buffer stored in layout */
int layout_number_merge_order; /* order in merge for layout */
char *name; /* buffer name */
char *full_name; /* plugin name + '.' + buffer name */
diff --git a/src/gui/gui-layout.h b/src/gui/gui-layout.h
index da6c24c36..527c51cf8 100644
--- a/src/gui/gui-layout.h
+++ b/src/gui/gui-layout.h
@@ -90,7 +90,7 @@ extern void gui_layout_buffer_get_number (struct t_gui_layout *layout,
int *layout_number,
int *layout_number_merge_order);
extern void gui_layout_buffer_get_number_all (struct t_gui_layout *layout);
-extern void gui_layout_buffer_save (struct t_gui_layout *layout);
+extern void gui_layout_buffer_store (struct t_gui_layout *layout);
extern void gui_layout_buffer_apply (struct t_gui_layout *layout);
extern void gui_layout_window_remove_all (struct t_gui_layout *layout);
@@ -104,12 +104,12 @@ extern struct t_gui_layout_window *gui_layout_window_add (struct t_gui_layout_wi
int split_horiz,
const char *plugin_name,
const char *buffer_name);
-extern void gui_layout_window_save (struct t_gui_layout *layout);
+extern void gui_layout_window_store (struct t_gui_layout *layout);
extern int gui_layout_window_check_buffer (struct t_gui_window *window);
extern void gui_layout_window_assign_buffer (struct t_gui_buffer *buffer);
extern void gui_layout_window_apply (struct t_gui_layout *layout,
int internal_id_current_window);
-extern void gui_layout_save_on_exit ();
+extern void gui_layout_store_on_exit ();
extern void gui_layout_free (struct t_gui_layout *layout);
extern void gui_layout_remove (struct t_gui_layout *layout);
extern void gui_layout_remove_all ();
diff --git a/src/core/wee-command.c b/src/core/wee-command.c
index f96ef3bf5..00a32cf03 100644
--- a/src/core/wee-command.c
+++ b/src/core/wee-command.c
@@ -3413,11 +3413,11 @@ COMMAND_CALLBACK(layout)
/* display all layouts */
if (argc == 1)
{
/* display saved layouts */
if (gui_layouts)
{
gui_chat_printf (NULL, "");
- gui_chat_printf (NULL, _("Saved layouts:"));
+ gui_chat_printf (NULL, _("Stored layouts:"));
for (ptr_layout = gui_layouts; ptr_layout;
ptr_layout = ptr_layout->next_layout)
{
@@ -3440,7 +3440,7 @@ COMMAND_CALLBACK(layout)
}
}
else
- gui_chat_printf (NULL, _("No layout saved"));
+ gui_chat_printf (NULL, _("No stored layouts"));
return WEECHAT_RC_OK;
}
@@ -3458,13 +3458,13 @@ COMMAND_CALLBACK(layout)
gui_layout_add (ptr_layout);
}
if (flag_buffers)
- gui_layout_buffer_save (ptr_layout);
+ gui_layout_buffer_store (ptr_layout);
if (flag_windows)
- gui_layout_window_save (ptr_layout);
+ gui_layout_window_store (ptr_layout);
gui_layout_current = ptr_layout;
gui_chat_printf (NULL,
/* TRANSLATORS: %s%s%s is "buffers" or "windows" or "buffers+windows" */
- _("Layout of %s%s%s saved in \"%s\" (current layout: %s)"),
+ _("Layout of %s%s%s stored in \"%s\" (current layout: %s)"),
(flag_buffers) ? _("buffers") : "",
(flag_buffers && flag_windows) ? "+" : "",
(flag_windows) ? _("windows") : "",
@@ -5666,8 +5666,8 @@ COMMAND_CALLBACK(upgrade)
weechat_quit = 1;
weechat_upgrading = 1;
- /* save layout, unload plugins, save config, then upgrade */
- gui_layout_save_on_exit ();
+ /* store layout, unload plugins, save config, then upgrade */
+ gui_layout_store_on_exit ();
plugin_end ();
if (CONFIG_BOOLEAN(config_look_save_config_on_exit))
(void) config_weechat_write ();
@@ -7005,17 +7005,17 @@ command_init ()
" || del [<name>] [buffers|windows]"
" || rename <name> <new_name>"),
N_(" store: store current buffers/windows in a layout\n"
- " apply: apply saved layout\n"
+ " apply: apply stored layout\n"
" leave: leave current layout (does not update any layout)\n"
- " del: delete buffers and/or windows in a saved layout\n"
+ " del: delete buffers and/or windows in a stored layout\n"
" (if neither \"buffers\" nor \"windows\" is given after "
"the name, the layout is deleted)\n"
" rename: rename a layout\n"
- " name: name for saved layout (default is \"default\")\n"
- "buffers: save/apply only buffers (order of buffers)\n"
- "windows: save/apply only windows (buffer displayed by each window)\n"
+ " name: name for stored layout (default is \"default\")\n"
+ "buffers: store/apply only buffers (order of buffers)\n"
+ "windows: store/apply only windows (buffer displayed by each window)\n"
"\n"
- "Without argument, this command displays saved layouts."),
+ "Without argument, this command displays stored layouts."),
"store %(layouts_names)|buffers|windows buffers|windows"
" || apply %(layouts_names)|buffers|windows buffers|windows"
" || leave"
@@ -3413,11 +3413,11 @@ COMMAND_CALLBACK(layout)
if (argc == 1)
{
- /* display saved layouts */
+ /* display stored layouts */
if (gui_layouts)
{
diff --git a/src/gui/gui-layout.c b/src/gui/gui-layout.c
index 31cd53cd0..d8932a63b 100644
--- a/src/gui/gui-layout.c
+++ b/src/gui/gui-layout.c
@@ -309,11 +309,11 @@ gui_layout_buffer_get_number_all (struct t_gui_layout *layout)
}
/*
- * Saves current layout for buffers in a layout.
+ * Stores current layout for buffers in a layout.
*/
void
-gui_layout_buffer_save (struct t_gui_layout *layout)
+gui_layout_buffer_store (struct t_gui_layout *layout)
{
struct t_gui_buffer *ptr_buffer;
@@ -521,11 +521,11 @@ gui_layout_window_add (struct t_gui_layout_window **layout_window,
}
/*
- * Saves tree of windows.
+ * Stores tree of windows.
*/
void
-gui_layout_window_save_tree (struct t_gui_layout *layout,
+gui_layout_window_store_tree (struct t_gui_layout *layout,
struct t_gui_layout_window **layout_windows,
struct t_gui_layout_window *parent_layout,
struct t_gui_window_tree *tree)
@@ -559,25 +559,25 @@ gui_layout_window_save_tree (struct t_gui_layout *layout,
if (tree->child1)
{
- gui_layout_window_save_tree (layout, layout_windows,
+ gui_layout_window_store_tree (layout, layout_windows,
layout_window, tree->child1);
}
if (tree->child2)
{
- gui_layout_window_save_tree (layout, layout_windows,
+ gui_layout_window_store_tree (layout, layout_windows,
layout_window, tree->child2);
}
}
/*
- * Saves current layout for windows in a layout.
+ * Stores current layout for windows in a layout.
*
* Returns internal id of current window.
*/
void
-gui_layout_window_save (struct t_gui_layout *layout)
+gui_layout_window_store (struct t_gui_layout *layout)
{
if (!layout)
return;
@@ -587,7 +587,7 @@ gui_layout_window_save (struct t_gui_layout *layout)
layout->internal_id = 1;
layout->internal_id_current_window = -1;
- gui_layout_window_save_tree (layout, &layout->layout_windows, NULL,
+ gui_layout_window_store_tree (layout, &layout->layout_windows, NULL,
gui_windows_tree);
}
@@ -759,15 +759,15 @@ gui_layout_window_apply (struct t_gui_layout *layout,
}
/*
* Saves layout according to option "save_layout_on_exit".
*/
void
-gui_layout_save_on_exit ()
+gui_layout_store_on_exit ()
{
struct t_gui_layout *ptr_layout;
- if (CONFIG_BOOLEAN(config_look_save_layout_on_exit) == CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_NONE)
+ if (CONFIG_BOOLEAN(config_look_store_layout_on_exit) == CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_NONE)
return;
ptr_layout = gui_layout_current;
@@ -784,18 +784,18 @@ gui_layout_save_on_exit ()
}
}
- /* save current layout */
- switch (CONFIG_BOOLEAN(config_look_save_layout_on_exit))
+ /* store current layout */
+ switch (CONFIG_BOOLEAN(config_look_store_layout_on_exit))
{
- case CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_BUFFERS:
- gui_layout_buffer_save (ptr_layout);
+ case CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_BUFFERS:
+ gui_layout_buffer_store (ptr_layout);
break;
- case CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_WINDOWS:
- gui_layout_window_save (ptr_layout);
+ case CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_WINDOWS:
+ gui_layout_window_store (ptr_layout);
break;
- case CONFIG_LOOK_SAVE_LAYOUT_ON_EXIT_ALL:
- gui_layout_buffer_save (ptr_layout);
- gui_layout_window_save (ptr_layout);
+ case CONFIG_LOOK_STORE_LAYOUT_ON_EXIT_ALL:
+ gui_layout_buffer_store (ptr_layout);
+ gui_layout_window_store (ptr_layout);
break;
default:
break;
@@ -759,15 +759,15 @@ gui_layout_window_apply (struct t_gui_layout *layout,
}
/*
- * Saves layout according to option "save_layout_on_exit".
+ * Stores layout according to option "store_layout_on_exit".
*/
void
diff --git a/src/gui/gui-window.c b/src/gui/gui-window.c
index d6adac7c1..e11817522 100644
--- a/src/gui/gui-window.c
+++ b/src/gui/gui-window.c
@@ -1667,14 +1667,14 @@ gui_window_zoom (struct t_gui_window *window)
}
else
{
/* save layout and zoom on current window */
ptr_layout = gui_layout_alloc (GUI_LAYOUT_ZOOM);
if (ptr_layout)
{
gui_layout_add (ptr_layout);
hook_signal_send ("window_zoom",
WEECHAT_HOOK_SIGNAL_POINTER, gui_current_window);
- gui_layout_window_save (ptr_layout);
+ gui_layout_window_store (ptr_layout);
gui_window_merge_all (window);
hook_signal_send ("window_zoomed",
WEECHAT_HOOK_SIGNAL_POINTER, gui_current_window);
@@ -1667,14 +1667,14 @@ gui_window_zoom (struct t_gui_window *window)
else
{
- /* save layout and zoom on current window */
+ /* store layout and zoom on current window */
ptr_layout = gui_layout_alloc (GUI_LAYOUT_ZOOM);
if (ptr_layout)